@@ -32,64 +32,65 @@
 /* reasonable guess as to size of 1024 events */
 #define BUF_LEN 	(1024 * (EVENT_SIZE + 16))
 
-static  void overwrite_database(cron_db *, cron_db *);
+static void overwrite_database(cron_db *, cron_db *);
 
-static	void		process_crontab(const char *, const char *,
-					const char *,
-					cron_db *, cron_db *);
+static void process_crontab(const char *, const char *,
+	const char *, cron_db *, cron_db *);
 
-static int not_a_crontab( DIR_T *dp ); 
+static int not_a_crontab(DIR_T * dp);
 /* return 1 if we should skip this file */
 
-static void max_mtime( char *dir_name, struct stat *max_st ); 
+static void max_mtime(char *dir_name, struct stat *max_st);
 /* record max mtime of any file under dir_name in max_st */
 
 static int
 check_open(const char *tabname, const char *fname, const char *uname,
-		struct passwd *pw, time_t *mtime) {
+	struct passwd *pw, time_t * mtime) {
 	struct stat statbuf;
 	int crontab_fd;
 	pid_t pid = getpid();
 
-	if ((crontab_fd = open(tabname, O_RDONLY|O_NONBLOCK|O_NOFOLLOW, 0)) == -1) {
+	if ((crontab_fd =
+			open(tabname, O_RDONLY | O_NONBLOCK | O_NOFOLLOW, 0)) == -1) {
 		log_it(uname, pid, "CAN'T OPEN", tabname, errno);
-		return(-1);
+		return (-1);
 	}
 	if (fstat(crontab_fd, &statbuf) < OK) {
 		log_it(uname, pid, "STAT FAILED", tabname, errno);
 		close(crontab_fd);
-		return(-1);
+		return (-1);
 	}
 	*mtime = statbuf.st_mtime;
 	if (PermitAnyCrontab == 0) {
 		if (!S_ISREG(statbuf.st_mode)) {
 			log_it(uname, pid, "NOT REGULAR", tabname, 0);
 			close(crontab_fd);
-			return(-1);
+			return (-1);
 		}
 		if ((statbuf.st_mode & 07533) != 0400) {
 			log_it(uname, pid, "BAD FILE MODE", tabname, 0);
 			close(crontab_fd);
-			return(-1);
+			return (-1);
 		}
 		if (statbuf.st_uid != ROOT_UID && (pw == NULL ||
-			statbuf.st_uid != pw->pw_uid || strcmp(uname, pw->pw_name) != 0)) {
+				statbuf.st_uid != pw->pw_uid ||
+				strcmp(uname, pw->pw_name) != 0)) {
 			log_it(uname, pid, "WRONG FILE OWNER", tabname, 0);
 			close(crontab_fd);
-			return(-1);
+			return (-1);
 		}
 		if (pw && statbuf.st_nlink != 1) {
 			log_it(uname, pid, "BAD LINK COUNT", tabname, 0);
 			close(crontab_fd);
-			return(-1);
+			return (-1);
 		}
 	}
-	return(crontab_fd);
+	return (crontab_fd);
 }
 
 static void
 process_crontab(const char *uname, const char *fname, const char *tabname,
-	cron_db *new_db, cron_db *old_db) {
+	cron_db * new_db, cron_db * old_db) {
 	struct passwd *pw = NULL;
 	int crontab_fd = -1;
 	user *u;
@@ -98,21 +99,22 @@ process_crontab(const char *uname, const char *fname, const char *tabname,
 
 	if (fname == NULL) {
 		/* must be set to something for logging purposes.
-		*/
+		 */
 		fname = "*system*";
-	} else if ((pw = getpwnam(uname)) == NULL) {
+	}
+	else if ((pw = getpwnam(uname)) == NULL) {
 		/* file doesn't have a user in passwd file.
-		*/
+		 */
 		log_it(uname, getpid(), "ORPHAN", "no passwd entry", 0);
 		goto next_crontab;
 	}
-	
+
 	if ((crontab_fd = check_open(tabname, fname, uname, pw, &mtime)) == -1)
 		goto next_crontab;
 
 	Debug(DLOAD, ("\t%s:", fname))
 
-	u = find_user(old_db, fname, crond_crontab ? tabname : NULL );	/* find user in old_db */
+		u = find_user(old_db, fname, crond_crontab ? tabname : NULL);	/* find user in old_db */
 
 	if (u != NULL) {
 		/* if crontab has not changed since we last read it
@@ -120,7 +122,7 @@ process_crontab(const char *uname, const char *fname, const char *tabname,
 		 */
 		if (u->mtime == mtime) {
 			Debug(DLOAD, (" [no change, using old data]"))
-			unlink_user(old_db, u);
+				unlink_user(old_db, u);
 			link_user(new_db, u);
 			goto next_crontab;
 		}
@@ -133,7 +135,7 @@ process_crontab(const char *uname, const char *fname, const char *tabname,
 		 * we finish with the crontab...
 		 */
 		Debug(DLOAD, (" [delete old data]"))
-		unlink_user(old_db, u);
+			unlink_user(old_db, u);
 		free_user(u);
 		log_it(fname, getpid(), "RELOAD", tabname, 0);
 	}
@@ -147,13 +149,12 @@ process_crontab(const char *uname, const char *fname, const char *tabname,
   next_crontab:
 	if (crontab_fd != -1) {
 		Debug(DLOAD, (" [done]\n"))
-		close(crontab_fd);
+			close(crontab_fd);
 	}
 }
 
 #if defined WITH_INOTIFY
-void
-check_inotify_database(cron_db *old_db) {
+void check_inotify_database(cron_db * old_db) {
 	cron_db new_db;
 	DIR_T *dp;
 	DIR *dir;
@@ -178,7 +179,8 @@ check_inotify_database(cron_db *old_db) {
 	else if (FD_ISSET(old_db->ifd, &rfds)) {
 		new_db.head = new_db.tail = NULL;
 		new_db.ifd = old_db->ifd;
-		while ((retval=read(old_db->ifd, buf, sizeof(buf))) == -1 && errno == EINTR);
+		while ((retval = read(old_db->ifd, buf, sizeof (buf))) == -1 &&
+			errno == EINTR) ;
 
 		if (retval == 0) {
 			/* this should not happen as the buffer is large enough */
@@ -192,7 +194,7 @@ check_inotify_database(cron_db *old_db) {
 			 */
 			(void) exit(ERROR_EXIT);
 		}
-		
+
 		/* we must reinstate the watches here - TODO reinstate only watches
 		 * which get IN_IGNORED event
 		 */
@@ -202,16 +204,18 @@ check_inotify_database(cron_db *old_db) {
 
 		process_crontab("root", NULL, SYSCRONTAB, &new_db, old_db);
 
-		if (!(dir = opendir(RH_CROND_DIR))) {
-			log_it("CRON", pid, "OPENDIR FAILED", RH_CROND_DIR, errno);
-		} else {
+		if (!(dir = opendir(SYS_CROND_DIR))) {
+			log_it("CRON", pid, "OPENDIR FAILED", SYS_CROND_DIR, errno);
+		}
+		else {
 			while (NULL != (dp = readdir(dir))) {
-				char tabname[MAXNAMLEN+1];
+				char tabname[MAXNAMLEN + 1];
 
 				if (not_a_crontab(dp))
 					continue;
 
-				if (!glue_strings(tabname, sizeof tabname, RH_CROND_DIR, dp->d_name, '/'))
+				if (!glue_strings(tabname, sizeof tabname, SYS_CROND_DIR,
+						dp->d_name, '/'))
 					continue;
 				process_crontab("root", NULL, tabname, &new_db, old_db);
 			}
@@ -220,16 +224,18 @@ check_inotify_database(cron_db *old_db) {
 
 		if (!(dir = opendir(SPOOL_DIR))) {
 			log_it("CRON", pid, "OPENDIR FAILED", SPOOL_DIR, errno);
-		} else {
+		}
+		else {
 			while (NULL != (dp = readdir(dir))) {
-				char fname[MAXNAMLEN+1], tabname[MAXNAMLEN+1];
+				char fname[MAXNAMLEN + 1], tabname[MAXNAMLEN + 1];
 
 				if (not_a_crontab(dp))
 					continue;
 
 				strncpy(fname, dp->d_name, MAXNAMLEN);
 
-				if (!glue_strings(tabname, sizeof tabname, SPOOL_DIR, dp->d_name, '/'))
+				if (!glue_strings(tabname, sizeof tabname, SPOOL_DIR,
+						dp->d_name, '/'))
 					continue;
 				process_crontab(fname, fname, tabname, &new_db, old_db);
 			}
@@ -252,54 +258,54 @@ check_inotify_database(cron_db *old_db) {
 }
 #endif
 
-static void
-overwrite_database(cron_db *old_db, cron_db *new_db) {
+static void overwrite_database(cron_db * old_db, cron_db * new_db) {
 	user *u, *nu;
 	/* whatever's left in the old database is now junk.
-	*/
+	 */
 	Debug(DLOAD, ("unlinking old database:\n"))
-	for (u = old_db->head;  u != NULL;  u = nu) {
+		for (u = old_db->head; u != NULL; u = nu) {
 		Debug(DLOAD, ("\t%s\n", u->name))
-		nu = u->next;
+			nu = u->next;
 		unlink_user(old_db, u);
 		free_user(u);
 	}
 
 	/* overwrite the database control block with the new one.
-	*/
+	 */
 	*old_db = *new_db;
 }
 
-int
-load_database(cron_db *old_db) {
+int load_database(cron_db * old_db) {
 	struct stat statbuf, syscron_stat, crond_stat;
 	cron_db new_db;
 	DIR_T *dp;
 	DIR *dir;
 	pid_t pid = getpid();
 
-	Debug(DLOAD, ("[%ld] load_database()\n", (long)pid))
+	Debug(DLOAD, ("[%ld] load_database()\n", (long) pid))
 
-	/* before we start loading any data, do a stat on SPOOL_DIR
-	 * so that if anything changes as of this moment (i.e., before we've
-	 * cached any of the database), we'll see the changes next time.
-	 */
-	if (stat(SPOOL_DIR, &statbuf) < OK) {
+		/* before we start loading any data, do a stat on SPOOL_DIR
+		 * so that if anything changes as of this moment (i.e., before we've
+		 * cached any of the database), we'll see the changes next time.
+		 */
+		if (stat(SPOOL_DIR, &statbuf) < OK) {
 		log_it("CRON", pid, "STAT FAILED", SPOOL_DIR, errno);
 		statbuf.st_mtime = 0;
-	} else {
+	}
+	else {
 		/* As pointed out in Red Hat bugzilla 198019, with modern Linux it
 		 * is possible to modify a file without modifying the mtime of the
 		 * containing directory. Hence, we must check the mtime of each file:
-	         */
+		 */
 		max_mtime(SPOOL_DIR, &statbuf);
 	}
 
-	if (stat(RH_CROND_DIR, &crond_stat) < OK) {
-		log_it("CRON", pid, "STAT FAILED", RH_CROND_DIR, errno);
+	if (stat(SYS_CROND_DIR, &crond_stat) < OK) {
+		log_it("CRON", pid, "STAT FAILED", SYS_CROND_DIR, errno);
 		crond_stat.st_mtime = 0;
-	} else {
-		max_mtime(RH_CROND_DIR, &crond_stat);
+	}
+	else {
+		max_mtime(SYS_CROND_DIR, &crond_stat);
 	}
 
 	/* track system crontab file
@@ -315,11 +321,11 @@ load_database(cron_db *old_db) {
 	 * time this function is called.
 	 */
 	if (old_db->mtime == TMAX(crond_stat.st_mtime,
-				  TMAX(statbuf.st_mtime, syscron_stat.st_mtime))
-	   ){
+			TMAX(statbuf.st_mtime, syscron_stat.st_mtime))
+		) {
 		Debug(DLOAD, ("[%ld] spool dir mtime unch, no load needed.\n",
-			      (long)pid))
-		return 0;
+				(long) pid))
+			return 0;
 	}
 
 	/* something's different.  make a new database, moving unchanged
@@ -328,7 +334,7 @@ load_database(cron_db *old_db) {
 	 * we're done is chaff -- crontabs that disappeared.
 	 */
 	new_db.mtime = TMAX(crond_stat.st_mtime,
-			    TMAX(statbuf.st_mtime, syscron_stat.st_mtime));
+		TMAX(statbuf.st_mtime, syscron_stat.st_mtime));
 	new_db.head = new_db.tail = NULL;
 #if defined WITH_INOTIFY
 	new_db.ifd = old_db->ifd;
@@ -337,16 +343,18 @@ load_database(cron_db *old_db) {
 	if (syscron_stat.st_mtime)
 		process_crontab("root", NULL, SYSCRONTAB, &new_db, old_db);
 
-	if (!(dir = opendir(RH_CROND_DIR))) {
-		log_it("CRON", pid, "OPENDIR FAILED", RH_CROND_DIR, errno);
-	} else {
+	if (!(dir = opendir(SYS_CROND_DIR))) {
+		log_it("CRON", pid, "OPENDIR FAILED", SYS_CROND_DIR, errno);
+	}
+	else {
 		while (NULL != (dp = readdir(dir))) {
-			char   tabname[MAXNAMLEN+1];
+			char tabname[MAXNAMLEN + 1];
 
-			if ( not_a_crontab( dp ) )
+			if (not_a_crontab(dp))
 				continue;
 
-			if (!glue_strings(tabname, sizeof tabname, RH_CROND_DIR, dp->d_name, '/'))
+			if (!glue_strings(tabname, sizeof tabname, SYS_CROND_DIR,
+					dp->d_name, '/'))
 				continue;	/* XXX log? */
 
 			process_crontab("root", NULL, tabname, &new_db, old_db);
@@ -361,11 +369,12 @@ load_database(cron_db *old_db) {
 
 	if (!(dir = opendir(SPOOL_DIR))) {
 		log_it("CRON", pid, "OPENDIR FAILED", SPOOL_DIR, errno);
-	} else {
+	}
+	else {
 		while (NULL != (dp = readdir(dir))) {
-			char fname[MAXNAMLEN+1], tabname[MAXNAMLEN+1];
+			char fname[MAXNAMLEN + 1], tabname[MAXNAMLEN + 1];
 
-			if ( not_a_crontab( dp ) )
+			if (not_a_crontab(dp))
 				continue;
 
 			strncpy(fname, dp->d_name, MAXNAMLEN);
@@ -386,11 +395,10 @@ load_database(cron_db *old_db) {
 
 	overwrite_database(old_db, &new_db);
 	Debug(DLOAD, ("load_database is done\n"))
-	return 1;
+		return 1;
 }
 
-void
-link_user(cron_db *db, user *u) {
+void link_user(cron_db * db, user * u) {
 	if (db->head == NULL)
 		db->head = u;
 	if (db->tail)
@@ -400,8 +408,7 @@ link_user(cron_db *db, user *u) {
 	db->tail = u;
 }
 
-void
-unlink_user(cron_db *db, user *u) {
+void unlink_user(cron_db * db, user * u) {
 	if (u->prev == NULL)
 		db->head = u->next;
 	else
@@ -413,21 +420,20 @@ unlink_user(cron_db *db, user *u) {
 		u->next->prev = u->prev;
 }
 
-user *
-find_user(cron_db *db, const char *name, const char *tabname) {
+user *find_user(cron_db * db, const char *name, const char *tabname) {
 	user *u;
 
-	for (u = db->head;  u != NULL;  u = u->next)
-	    if (  (strcmp(u->name, name) == 0) 
-		&&(   (tabname == NULL) 
-		   || ( strcmp(tabname, u->tabname) == 0 )
-		  )
-	       ) break;
+	for (u = db->head; u != NULL; u = u->next)
+		if ((strcmp(u->name, name) == 0)
+			&& ((tabname == NULL)
+				|| (strcmp(tabname, u->tabname) == 0)
+			)
+			)
+			break;
 	return (u);
 }
 
-static int not_a_crontab( DIR_T *dp )
-{
+static int not_a_crontab(DIR_T * dp) {
 	int len;
 
 	/* avoid file names beginning with ".".  this is good
@@ -436,33 +442,32 @@ static int not_a_crontab( DIR_T *dp )
 	 * hidden files in here anyway
 	 */
 	if (dp->d_name[0] == '.')
-		return(1);
+		return (1);
 
 	/* ignore files starting with # and ending with ~ */
 	if (dp->d_name[0] == '#')
-		return(1);
+		return (1);
 
 	len = strlen(dp->d_name);
 
 	if (len >= MAXNAMLEN)
-		return(1);	/* XXX log? */
+		return (1);	/* XXX log? */
 
 	if ((len > 0) && (dp->d_name[len - 1] == '~'))
-		return(1);
+		return (1);
 
 	if ((len > 8) && (strncmp(dp->d_name + len - 8, ".rpmsave", 8) == 0))
-		return(1);
+		return (1);
 	if ((len > 8) && (strncmp(dp->d_name + len - 8, ".rpmorig", 8) == 0))
-		return(1);
+		return (1);
 	if ((len > 7) && (strncmp(dp->d_name + len - 7, ".rpmnew", 7) == 0))
-		return(1);
+		return (1);
 
-	return(0);
+	return (0);
 }
 
-static void max_mtime( char *dir_name, struct stat *max_st )
-{
-	DIR * dir;
+static void max_mtime(char *dir_name, struct stat *max_st) {
+	DIR *dir;
 	DIR_T *dp;
 	struct stat st;
 
@@ -471,21 +476,20 @@ static void max_mtime( char *dir_name, struct stat *max_st )
 		return;
 	}
 
-	while (NULL != (dp = readdir(dir))) 
-	{
-		char tabname[MAXNAMLEN+1];
+	while (NULL != (dp = readdir(dir))) {
+		char tabname[MAXNAMLEN + 1];
 
-		if ( not_a_crontab ( dp ) )
+		if (not_a_crontab(dp))
 			continue;
 
 		if (!glue_strings(tabname, sizeof tabname, dir_name, dp->d_name, '/'))
 			continue;	/* XXX log? */
 
-		if ( stat( tabname, &st ) < OK )
-			continue;       /* XXX log? */
-		
-		if ( st.st_mtime > max_st->st_mtime )
-			max_st->st_mtime = st.st_mtime;		
+		if (stat(tabname, &st) < OK)
+			continue;	/* XXX log? */
+
+		if (st.st_mtime > max_st->st_mtime)
+			max_st->st_mtime = st.st_mtime;
 	}
 	closedir(dir);
 }
